@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -81,7 +81,6 @@ static void defoperation_update		(GtkWidget *widget, gpointer user_data);
 //static gboolean defoperation_cleanup(struct defoperation_data *data, gint result);
 static void defoperation_setup(struct defoperation_data *data);
 static void defoperation_set(GtkWidget *widget, gpointer user_data);
-static void defoperation_update_child_transfer(Operation *src, Operation *dst);
 static void defoperation_update_transfer(GtkWidget *widget, gpointer user_data);
 
 extern gchar *CYA_TYPE[];
@@ -110,7 +109,7 @@ gchar *tagstr, *txt;
 
 	DB( g_printf(" -> ope=%8x data=%x\n", (gint)data->ope, data) );
 
-	DB( g_print(" -> tags at: '%x'\n", entry->tags) );
+	DB( g_printf(" -> tags at: '%x'\n", entry->tags) );
 
 
 	//DB( g_printf(" set date to %d\n", entry->date) );
@@ -155,7 +154,7 @@ gchar *tagstr, *txt;
 void defoperation_get(GtkWidget *widget, gpointer user_data)
 {
 struct defoperation_data *data;
-Operation *entry, *child;
+Operation *entry;
 gchar *txt;
 gdouble value;
 gint active;
@@ -168,24 +167,6 @@ gint active;
 
 	DB( g_printf(" -> ope = %x\n", entry) );
 
-	/* look and store for a child transfer operation */
-	child = NULL;	
-	if( entry->paymode == PAYMODE_INTXFER && data->type == OPERATION_EDIT_MODIFY )
-	{
-		DB( g_print(" search: %d %s %f %d=>%d\n", entry->date, entry->wording, entry->amount, entry->account, entry->dst_account) );
-
-		child = operation_get_child_transfer( entry );
-		if( child == NULL )
-		{
-			/* warn the user we have not found the child internal transfer */
-			operation_warn_transfer( entry, _("Could not propagate changes to child transfer:\n\n"
-				"account:  %s\n"
-				"date:  %s\n"
-				"amount:  %s\n"
-				"\nYou should fix the problem manually.") );
-		}
-	}
-
 	//DB( g_printf(" get date to %d\n", entry->ope_Date) );
 	entry->date = gtk_dateentry_get_date(GTK_DATE_ENTRY(data->PO_date));
 	//g_object_get(GTK_DATE_ENTRY(data->PO_date), "date", entry->ope_Date);
@@ -230,19 +211,15 @@ gint active;
 		entry->info = g_strdup(txt);
 	}
 
-	entry->category    = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_grp));
-	entry->payee       = ui_pay_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_pay));
+	entry->category    = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX_ENTRY(data->PO_grp));
+	entry->payee       = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX_ENTRY(data->PO_pay));
 	entry->account     = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_acc));
 	entry->dst_account = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_accto));
 
 	/* tags */
 	txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_tags));
-	if (txt && *txt)
-	{
-		DB( g_print(" -> tags: '%s'\n", txt) );
-		
-		transaction_set_tags(entry, txt);
-	}
+	DB( g_print(" -> tags: '%s'\n", txt) );
+	transaction_set_tags(entry, txt);
 
 	/* flags */
 	entry->flags &= (OF_AUTO|OF_ADDED);
@@ -266,12 +243,6 @@ gint active;
 	active = entry->amount > 0 ? TRUE : FALSE;
 	if(active == TRUE) entry->flags |= OF_INCOME;
 
-	// update the child transfer if necessary
-	if( child != NULL )
-	{
-		defoperation_update_child_transfer(entry, child);
-	}
-
 }
 
 
@@ -488,6 +459,8 @@ gboolean sensitive, bool;
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_remind), 0);
 
 	/* transfer integrity */
+	//todo: see bug with transfer
+/*
 	sensitive = TRUE;
 	if( data->type == OPERATION_EDIT_MODIFY && data->ope !=NULL )
 	{
@@ -500,7 +473,8 @@ gboolean sensitive, bool;
 	gtk_widget_set_sensitive(data->PO_acc, sensitive);
 	gtk_widget_set_sensitive(data->PO_accto, sensitive);
 	gtk_widget_set_sensitive(data->NU_mode, sensitive);
-	
+*/
+	 
 }
 
 /*
@@ -547,37 +521,6 @@ gint n_arc;
 	}
 }
 
-static void defoperation_update_child_transfer(Operation *src, Operation *dst)
-{
-Account *acc;
-gboolean active;
-
-	DB( g_print("(ui_operation) update child transfer\n") );
-
-	/* update the child transfer */
-	dst->date     = src->date;
-	dst->amount	  = -src->amount;
-	dst->payee	  = src->payee;
-	dst->category = src->category;
-	dst->flags    = src->flags;
-	if( dst->wording ) { g_free(dst->wording); dst->wording = NULL; }
-	if( src->wording ) dst->wording = g_strdup(src->wording);
-	if( dst->info ) { g_free(dst->info); dst->info = NULL; }
-	if( src->info ) dst->info = g_strdup(src->info);
-
-	dst->flags ^= OF_INCOME;			
-	active = dst->amount > 0 ? TRUE : FALSE;
-	if(active == TRUE) dst->flags |= OF_INCOME;
-
-	/* mark account as changed */
-	acc = da_acc_get( src->dst_account );
-	if( acc)
-		acc->flags |= AF_CHANGED;
-
-}
-
-
-
 
 void defoperation_dispose(GtkWidget *widget, gpointer user_data)
 {
@@ -637,9 +580,9 @@ static void defoperation_setup(struct defoperation_data *data)
 
 
 
-static GtkWidget *defoperation_make_block2(struct defoperation_data *data)
+static GtkWidget *defoperation_make_block1(struct defoperation_data *data)
 {
-GtkWidget *table, *hbox, *label, *widget;
+GtkWidget *table, *hbox, *label, *widget, *notebook;
 gint row;
 
 	table = gtk_table_new (7, 3, FALSE);
@@ -667,14 +610,6 @@ gint row;
 
 	gtk_widget_set_tooltip_text(widget, _("Date accepted here are:\nday,\nday/month or month/day,\nand complete date into your locale"));
 
-	row++;
-	label = gtk_label_new_with_mnemonic (_("_Description:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	//widget = make_string(label);
-	widget = make_memo_entry(label);
-	data->ST_word = widget;
-	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
 	//row 3
 	row++;
@@ -694,46 +629,26 @@ gint row;
 	gtk_table_attach (GTK_TABLE (table), hbox, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
 	row++;
-	label = gtk_label_new_with_mnemonic (_("A_ccount:"));
+	label = gtk_label_new_with_mnemonic (_("_Payee:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = ui_acc_comboboxentry_new(label);
-	data->PO_acc = widget;
-	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = ui_pay_comboboxentry_new(label);
+	data->PO_pay = widget;
+	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
+
+	gtk_widget_set_tooltip_text(widget, _("Autocompletion and direct seizure\nis available for Payee"));
 
 	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("_Validated"));
-	data->CM_valid = widget;
-	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 3, row, row+1);
+	label = gtk_label_new_with_mnemonic (_("_Category:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = ui_cat_comboboxentry_new(label);
+	data->PO_grp = widget;
+	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
 
-	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("_Remind"));
-	data->CM_remind = widget;
-	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 3, row, row+1);
-
-	return table;
-}
-
-static GtkWidget *defoperation_make_block3(struct defoperation_data *data)
-{
-GtkWidget *table, *hbox, *label, *widget, *notebook;
-gint row;
-
-	table = gtk_table_new (6, 3, FALSE);
-	//gtk_container_set_border_width (GTK_CONTAINER (table), HB_BOX_SPACING);
-	gtk_table_set_row_spacings (GTK_TABLE (table), HB_TABROW_SPACING);
-	gtk_table_set_col_spacings (GTK_TABLE (table), HB_TABCOL_SPACING);
-
-	row = 0;
-	label = make_label(NULL, 0.0, 0.0);
-	gtk_label_set_markup (GTK_LABEL(label), _("<b>Optional information</b>"));
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 3, row, row+1);
-
-	row++;
-	label = make_label("", 0.0, 0.5);
-	gtk_misc_set_padding (GTK_MISC (label), HB_BOX_SPACING, 0);
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_widget_set_tooltip_text(widget, _("Autocompletion and direct seizure\nis available for Category"));
 
+		row++;
 	label = gtk_label_new_with_mnemonic (_("Pay_ment:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
@@ -765,6 +680,39 @@ gint row;
 		data->PO_accto = widget;
 		gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
+	
+	return table;
+}
+
+static GtkWidget *defoperation_make_block2(struct defoperation_data *data)
+{
+GtkWidget *table, *label, *widget;
+gint row;
+
+	table = gtk_table_new (6, 3, FALSE);
+	//gtk_container_set_border_width (GTK_CONTAINER (table), HB_BOX_SPACING);
+	gtk_table_set_row_spacings (GTK_TABLE (table), HB_TABROW_SPACING);
+	gtk_table_set_col_spacings (GTK_TABLE (table), HB_TABCOL_SPACING);
+
+	row = 0;
+	label = make_label(NULL, 0.0, 0.0);
+	gtk_label_set_markup (GTK_LABEL(label), _("<b>Optional information</b>"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 3, row, row+1);
+
+	row++;
+	label = make_label("", 0.0, 0.5);
+	gtk_misc_set_padding (GTK_MISC (label), HB_BOX_SPACING, 0);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
+
+	label = gtk_label_new_with_mnemonic (_("_Description:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	//widget = make_string(label);
+	widget = make_memo_entry(label);
+	data->ST_word = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
 	row++;
 	label = gtk_label_new_with_mnemonic (_("_Info:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
@@ -774,26 +722,6 @@ gint row;
 	data->ST_info = widget;
 	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
 
-	row++;
-	label = gtk_label_new_with_mnemonic (_("_Payee:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = ui_pay_comboboxentry_new(label);
-	data->PO_pay = widget;
-	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
-
-	gtk_widget_set_tooltip_text(widget, _("Autocompletion and direct seizure\nis available for Payee"));
-
-	row++;
-	label = gtk_label_new_with_mnemonic (_("_Category:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	widget = ui_cat_comboboxentry_new(label);
-	data->PO_grp = widget;
-	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
-
-	gtk_widget_set_tooltip_text(widget, _("Autocompletion and direct seizure\nis available for Category"));
-
 	row++;
 	label = gtk_label_new_with_mnemonic (_("_Tags:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
@@ -802,6 +730,24 @@ gint row;
 	data->ST_tags = widget;
 	gtk_table_attach_defaults (GTK_TABLE (table), widget, 2, 3, row, row+1);
 
+	row++;
+	label = gtk_label_new_with_mnemonic (_("A_ccount:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = ui_acc_comboboxentry_new(label);
+	data->PO_acc = widget;
+	gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("_Validated"));
+	data->CM_valid = widget;
+	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 3, row, row+1);
+	
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("_Remind"));
+	data->CM_remind = widget;
+	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 3, row, row+1);
+
 	return table;
 }
 
@@ -892,17 +838,17 @@ GtkWidget *alignment;
 	gtk_box_pack_start (GTK_BOX (mainbox), hbox, TRUE, TRUE, 0);
 
 	// frame 2
-	table = defoperation_make_block2(data);
+	table = defoperation_make_block1(data);
 	//			gtk_alignment_new(xalign, yalign, xscale, yscale)
-	alignment = gtk_alignment_new(0.5, 0, 1.0, 0.0);
+	alignment = gtk_alignment_new(0.5, 0.0, 1.0, 0.0);
 	gtk_container_add(GTK_CONTAINER(alignment), table);
 	gtk_box_pack_start (GTK_BOX (hbox), alignment, TRUE, TRUE, 0);
 
 
 	// frame 3
-	table = defoperation_make_block3(data);
+	table = defoperation_make_block2(data);
 	//			gtk_alignment_new(xalign, yalign, xscale, yscale)
-	alignment = gtk_alignment_new(0.5, 0, 1.0, 0.0);
+	alignment = gtk_alignment_new(0.5, 0.0, 0.0, 0.0);
 	gtk_container_add(GTK_CONTAINER(alignment), table);
 	gtk_box_pack_start (GTK_BOX (hbox), alignment, TRUE, TRUE, 0);
 
@@ -913,10 +859,10 @@ GtkWidget *alignment;
 		gtk_box_pack_start (GTK_BOX (mainbox), hbox, FALSE, FALSE, 0);
 
 		label = make_label(_("_Fill with archive:"), 0, 0.5);
-		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 		widget = make_poparchive(label);
 		data->PO_arc = widget;
-		gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+		gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+		gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 		g_signal_connect (data->PO_arc, "changed", G_CALLBACK (defoperation_fillfrom), NULL);
 	}
