@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -109,6 +109,8 @@ struct defpref_data
 
 	GtkWidget	*CM_chartlegend;
 
+	GtkWidget	*CY_dtex_ofxmemo;
+
 };
 
 enum {
@@ -126,9 +128,9 @@ enum
 	PREF_INTERFACE,
 	PREF_COLUMNS,
 	PREF_DISPLAY,
-//	PREF_HELP,
-	PREF_EURO,
+	PREF_IMPORT,
 	PREF_REPORT,
+	PREF_EURO,
 	PREF_MAX
 };
 
@@ -148,9 +150,9 @@ static gchar *pref_pixname[PREF_MAX] = {
 "prf-interface",
 "prf-columns",
 "prf-display",
-//"prf_help.svg",
+"prf-import",
+"prf-report",
 "prf-euro",
-"prf-report"
 //"prf_charts.svg"
 };
 
@@ -159,9 +161,9 @@ N_("General"),
 N_("Interface"),
 N_("Columns"),
 N_("Display format"),
-//N_("Help system"),
-N_("Euro options"),
+N_("Import options"),
 N_("Report options"),
+N_("Euro options")
 //
 };
 
@@ -182,6 +184,15 @@ N_("Tango dark"),
 NULL
 };
 
+gchar *CYA_IMPORT_OFXMEMO[] = {
+N_("Ignore"),
+N_("Add to info"),
+N_("Add to description"),
+NULL
+};
+
+
+
 
 extern gchar *CYA_RANGE[];
 
@@ -658,8 +669,11 @@ GdkColor color;
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_budg_showdetail), PREFS->budg_showdetail);
 
-	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_chartlegend), PREFS->chart_legend);
+	/* import */
+	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_dtex_ofxmemo), PREFS->dtex_ofxmemo);
+	
 
+	
 }
 
 
@@ -783,6 +797,10 @@ GdkColor color;
 
 	PREFS->budg_showdetail = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_budg_showdetail));
 
+	/* import */
+	PREFS->dtex_ofxmemo = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_dtex_ofxmemo));
+
+	
 	//PREFS->chart_legend = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_chartlegend));
 
 }
@@ -823,6 +841,41 @@ gint row;
 */
 
 
+static GtkWidget *defpref_page_import (struct defpref_data *data)
+{
+GtkWidget *container;
+GtkWidget *table, *label, *widget;
+gint row;
+
+	container = gtk_vbox_new(FALSE, 0);
+
+	table = gtk_table_new (5, 2, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (table), HB_BOX_SPACING);
+	gtk_table_set_row_spacings (GTK_TABLE (table), HB_TABROW_SPACING);
+	gtk_table_set_col_spacings (GTK_TABLE (table), HB_TABCOL_SPACING);
+
+	gtk_box_pack_start (GTK_BOX (container), table, FALSE, FALSE, 0);
+
+	row = 0;
+	label = make_label(NULL, 0.0, 0.0);
+	gtk_label_set_markup (GTK_LABEL(label), _("<b>OFX/QFX options</b>"));
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 2, row, row+1);
+
+	row++;
+	label = make_label(_("Import _memo field:"), 0, 0.5);
+	//----------------------------------------- l, r, t, b
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = make_cycle(label, CYA_IMPORT_OFXMEMO);
+	data->CY_dtex_ofxmemo = widget;
+	//gtk_table_attach_defaults (GTK_TABLE (table), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
+	gtk_table_attach (GTK_TABLE (table), widget, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+
+
+	return(container);
+}
+
+
+
 
 static GtkWidget *defpref_page_reports (struct defpref_data *data)
 {
@@ -1699,18 +1752,19 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *frame, *image, *label;
 	page = defpref_page_display(&data);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, NULL);
 
-	//help
-	//page = defpref_page_help(&data);
-	//gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, NULL);
-
-	//euro
-	page = defpref_page_euro(&data);
+	//import
+	page = defpref_page_import(&data);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, NULL);
 
 	//report
 	page = defpref_page_reports(&data);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, NULL);
 
+	//euro
+	page = defpref_page_euro(&data);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, NULL);
+
+	
 	//todo:should move this
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data.CM_euro_enable), PREFS->euro_active);
 
