@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -94,7 +94,8 @@ struct account_data
 
 	double	bank, today, future;
 
-	Operation ope;
+	Operation cur_ope;
+	Operation bak_ope;
 	gint accnum;
 	Account *acc;
 
@@ -336,224 +337,6 @@ gboolean usermode = TRUE;
 
 
 /* these 5 functions are independant from account window */
-Operation *
-operation_get_child_transfer(Operation *src)
-{
-GList *list;
-Operation *item;
-
-	DB( g_print("(operation) operation_get_child_transfer\n") );
-
-	DB( g_print(" search: %d %s %f %d=>%d\n", src->date, src->wording, src->amount, src->account, src->dst_account) );
-
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
-	{
-		item = list->data;
-		if( item->paymode == PAYMODE_INTXFER)
-		{
-			if( src->date == item->date &&
-			    src->account == item->dst_account &&
-			    src->dst_account == item->account &&
-			    ABS(src->amount) == ABS(item->amount) )
-			{
-				DB( g_print(" found : %d %s %f %d=>%d\n", item->date, item->wording, item->amount, item->account, item->dst_account) );
-
-				return item;			
-			}
-		}
-		list = g_list_next(list);
-	}		
-
-	DB( g_print(" not found...\n") );
-
-	return NULL;
-}
-
-
-void operation_warn_transfer(Operation *src, gchar *msg2)
-{
-gchar str_amount[128];
-gchar str_date[128];
-GDate *date;
-Account *acc;
-gchar *accname;
-
-	DB( g_print("(operation) operation_warn_transfer\n") );
-	
-		
-		mystrfmon(str_amount, 127, src->amount, 0);
-
-		date = g_date_new_julian (src->date);
-		g_date_strftime (str_date, 128-1, PREFS->date_format, date);
-		g_date_free(date);
-		
-		acc = da_acc_get( src->dst_account);
-		
-		//fix 379760
-		accname = _("Unknown");
-		if( acc != NULL )
-			accname = acc->name;
-		
-		//warn the user
-		homebank_message_dialog(NULL, GTK_MESSAGE_INFO,
-			_("No corresponding transfer can be found."),
-			msg2,
-			accname,	//account name
-			str_date,	//date
-			str_amount 	//amount
-			
-			);
-
-
-}
-
-void operation_delete_child_transfer(Operation *src)
-{
-Operation *dst;
-
-	DB( g_printf("(operation) delete_child_transfer\n") );
-
-	dst = operation_get_child_transfer( src );
-	
-	DB( g_print(" -> return is %s, %d\n", dst, dst) );
-	
-	if( dst == NULL )
-	{
-		/* warn the useer we have notfound the child internal transfer */
-		operation_warn_transfer( src, _("Could not delete child transfer:\n\n"
-			"account:  %s\n"
-			"date:  %s\n"
-			"amount:  %s\n"
-			"\nYou should fix the problem manually.") );
-	}
-	else
-	{
-		DB( g_print("deleting...") );
-		
-		GLOBALS->ope_list = g_list_remove(GLOBALS->ope_list, dst);
-	}
-}
-
-static void operation_add_transfer(Operation *ope, GtkWidget *treeview)
-{
-Operation *newope;
-Account *acc;
-gchar swap;
-
-	DB( g_printf("(operation) operation add transfer\n") );
-
-	if( ope->dst_account > 0 )
-	{
-		newope = da_operation_clone(ope);
-
-		newope->amount = -newope->amount;
-		newope->flags ^= (OF_INCOME);	//xor
-		newope->flags &= (~OF_REMIND);
-
-		swap = newope->account;
-		newope->account = newope->dst_account;
-		newope->dst_account = swap;
-
-
-		/* update acc flags */
-		acc = da_acc_get( newope->account);
-		if(acc != NULL)
-			acc->flags |= AF_ADDED;
-
-
-		DB( g_printf(" + add transfer, %x\n", newope) );
-
-		da_operation_append(newope);
-		if(treeview != NULL) operation_add_treeview(newope, treeview, ope->account);
-	}
-
-}
-
-void operation_add(Operation *ope, GtkWidget *treeview, gint accnum)
-{
-Operation *newope;
-Account *acc;
-
-	DB( g_printf("(operation) operation add\n") );
-
-	//allocate a new entry and copy from our edited structure
-	newope = da_operation_clone(ope);
-
-	//init flag and keep remind state
-	// already done in defoperation_get
-	//ope->flags |= (OF_ADDED);
-	//remind = (ope->flags & OF_REMIND) ? TRUE : FALSE;
-	//ope->flags &= (~OF_REMIND);
-
-	/* cheque number is already stored in defoperation_get */
-	/* todo:move this to operation add
-		store a new cheque number into account ? */
-		
-	if( (newope->info) && (newope->paymode == PAYMODE_CHECK) && !(newope->flags & OF_INCOME) )
-	{
-	Account *acc;
-	guint cheque;
-
-		/* get the active account and the corresponding cheque number */
-		acc = da_acc_get( newope->account);
-		cheque = atol(newope->info);
-
-		DB( g_printf(" -> should store cheque number %d to %d", cheque, newope->account) );
-		if( newope->flags & OF_CHEQ2 )
-			acc->cheque2 = cheque;
-		else
-			acc->cheque1 = cheque;
-	}
-
-
-	/* add normal operation */
-	acc = da_acc_get( ope->account);
-	if(acc != NULL)
-		acc->flags |= AF_ADDED;
-
-	DB( g_printf(" + add normal %x\n", newope) );
-	da_operation_append(newope);
-	if(treeview != NULL) operation_add_treeview(newope, treeview, accnum);
-
-	if(ope->paymode == PAYMODE_INTXFER)
-	{
-		operation_add_transfer(ope, treeview);
-	}
-}
-
-
-
-
-void operation_add_treeview(Operation *ope, GtkWidget *treeview, gint accnum)
-{
-GtkTreeModel *model;
-GtkTreeIter  iter;
-//GtkTreePath *path;
-//GtkTreeSelection *sel;
-
-	DB( g_printf("(operation) operation add treeview\n") );
-
-	if(ope->account == accnum)
-	{
-		model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
-		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-
-		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-				LST_DSPOPE_DATAS, ope,
-				-1);
-	
-		//activate that new line
-		//path = gtk_tree_model_get_path(model, &iter);
-		//gtk_tree_view_expand_to_path(GTK_TREE_VIEW(treeview), path);
-		
-		//sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
-		//gtk_tree_selection_select_iter(sel, &iter);
-		
-		//gtk_tree_path_free(path);
-	
-	}
-}
 
 /* account functions -------------------- */
 
@@ -617,7 +400,7 @@ GIOChannel *io;
 				payee = da_pay_get(ope->payee);
 				payeename = (payee->name == NULL) ? "" : payee->name;
 				category = da_cat_get(ope->category);
-				categoryname = (category->name == NULL) ? "" : category->name;
+				categoryname = (category->name == NULL) ? "" : da_cat_get_fullname(category);
 
 
 				g_ascii_dtostr (amountbuf, sizeof (amountbuf), ope->amount);
@@ -773,7 +556,7 @@ GDate *date;
 	if(g_list_length(GLOBALS->ope_list) == 0) return;
 
 	//get our min max date
-	da_operation_sort(GLOBALS->ope_list);
+	GLOBALS->ope_list = da_operation_sort(GLOBALS->ope_list);
 	list = g_list_first(GLOBALS->ope_list);
 	data->filter->mindate = ((Operation *)list->data)->date;
 	list = g_list_last(GLOBALS->ope_list);
@@ -804,10 +587,8 @@ GDate *date;
 }
 
 /*
-*	update balance with data->ope amount for the active account (data->accnum)
-*	call operation_add with data->ope, data->accnum
-*
-*
+*	update balance with data->cur_ope amount for the active account (data->accnum)
+*	call operation_add with data->cur_ope, data->accnum
 */
 static void account_add(GtkWidget *widget, gpointer user_data)
 {
@@ -817,7 +598,7 @@ Operation *ope;
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	DB( g_printf("(account) add (data=%08x)\n", data) );
 
-	ope = &data->ope;
+	ope = &data->cur_ope;
 	if(ope->account == data->accnum)
 	{
 		DB( g_printf(" -> update balance %.2f\n", ope->amount) );
@@ -1086,18 +867,18 @@ gboolean result;
 			date = GLOBALS->today;
 			account = data->accnum;
 
-			DB( g_printf(" -> ope=%8x\n", &data->ope) );
+			DB( g_printf(" -> ope=%8x\n", &data->cur_ope) );
 
-			window = create_defoperation_window(GTK_WINDOW(data->window), &data->ope, OPERATION_EDIT_ADD, data->accnum);
+			window = create_defoperation_window(GTK_WINDOW(data->window), &data->cur_ope, OPERATION_EDIT_ADD, data->accnum);
 			result = GTK_RESPONSE_ADD;
 			while(result == GTK_RESPONSE_ADD)
 			{
 				/* fill in the operation */
-				memset(&data->ope, 0, sizeof(Operation));
-				data->ope.date    = date;
-				data->ope.account = data->accnum;
+				memset(&data->cur_ope, 0, sizeof(Operation));
+				data->cur_ope.date    = date;
+				data->cur_ope.account = data->accnum;
 
-				defoperation_set_operation(window, &data->ope);
+				defoperation_set_operation(window, &data->cur_ope);
 
 				result = gtk_dialog_run (GTK_DIALOG (window));
 
@@ -1115,8 +896,8 @@ gboolean result;
 				}
 
 				//keep these values for next
-				date = data->ope.date;
-				account = data->ope.account;
+				date = data->cur_ope.date;
+				account = data->cur_ope.account;
 
 				//DB( g_printf(" -> result %d\n", result) );
 			}
@@ -1137,23 +918,23 @@ gboolean result;
 			ope = get_active_operation(GTK_TREE_VIEW(data->LV_ope));
 			if(ope)
 			{
-				window = create_defoperation_window(GTK_WINDOW(data->window), &data->ope, OPERATION_EDIT_INHERIT, data->accnum);
+				window = create_defoperation_window(GTK_WINDOW(data->window), &data->cur_ope, OPERATION_EDIT_INHERIT, data->accnum);
 				result = GTK_RESPONSE_ADD;
 				while(result == GTK_RESPONSE_ADD)
 				{
 					/* fill in the operation */
 
-					memcpy(&data->ope, ope, sizeof(Operation));
-					data->ope.wording = g_strdup(ope->wording);
-					data->ope.info    = g_strdup(ope->info);
+					memcpy(&data->cur_ope, ope, sizeof(Operation));
+					data->cur_ope.wording = g_strdup(ope->wording);
+					data->cur_ope.info    = g_strdup(ope->info);
 
 					//fix: 318733
 					if( PREFS->heritdate == FALSE )
 					{
-						data->ope.date = GLOBALS->today;
+						data->cur_ope.date = GLOBALS->today;
 					}
 
-					defoperation_set_operation(window, &data->ope);
+					defoperation_set_operation(window, &data->cur_ope);
 
 					result = gtk_dialog_run (GTK_DIALOG (window));
 
@@ -1186,9 +967,9 @@ gboolean result;
 			ope = get_active_operation(GTK_TREE_VIEW(data->LV_ope));
 			if(ope)
 			{
-				memcpy(&data->ope, ope, sizeof(Operation));
+				memcpy(&data->cur_ope, ope, sizeof(Operation));
 
-				oldope = &data->ope;
+				oldope = &data->cur_ope;
 				window = create_defoperation_window(GTK_WINDOW(data->window), ope, OPERATION_EDIT_MODIFY, data->accnum);
 
 				defoperation_set_operation(window, ope);
@@ -1206,9 +987,16 @@ gboolean result;
 						if(ope->flags & OF_VALID)
 							data->bank -= oldope->amount;
 					}
+					//delete any child transfer
+					if( ope->paymode == PAYMODE_INTXFER )
+					{
+						operation_delete_child_transfer(ope);
+					}
+
 					
 					defoperation_get(window, NULL);
 
+
 					//add our new amount to balances if ope->account == this account
 					if( ope->account == data->accnum )
 					{					
@@ -1239,8 +1027,6 @@ gboolean result;
 							//todo:sould create the transeftr also
 							operation_add_transfer(ope, data->LV_ope);
 						}
-						// synchronisation is done in operation_get method using defoperation_update_child_transfer
-
 					}
 
 					account_update(widget, GINT_TO_POINTER(UF_BALANCE));
@@ -1298,9 +1084,13 @@ gboolean result;
 				model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
 				selection = gtk_tree_selection_get_selected_rows(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope)), &model);
 
+				g_object_ref(model); /* Make sure the model stays with us after the tree view unrefs it */
+				gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_ope), NULL); /* Detach model from view */
+				
+
 				DB( g_printf(" delete %d line\n", g_list_length(selection)) );
 
-
+  
 				list = g_list_last(selection);
 				while(list != NULL)
 				{
@@ -1342,6 +1132,9 @@ gboolean result;
 				g_list_foreach(selection, (GFunc)gtk_tree_path_free, NULL);
 				g_list_free(selection);
 
+			  	gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_ope), model); /* Re-attach model to view */
+			  	g_object_unref(model);
+				
 				account_update(widget, GINT_TO_POINTER(UF_BALANCE));
 
 				data->acc->flags |= AF_CHANGED;
@@ -1430,7 +1223,6 @@ struct account_data *data;
 GtkTreeSelection *selection;
 gint flags;
 gint count = 0;
-gboolean minor;
 
 	DB( g_printf("****\n(account) update\n") );
 
@@ -1439,7 +1231,7 @@ gboolean minor;
 
 	flags = (gint)user_data;
 
-		minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
+		GLOBALS->minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
 
 
 	/* set window title */
@@ -1518,9 +1310,9 @@ gboolean minor;
 		DB( printf(" +  4: balances\n") );
 
 
-		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[0]), data->bank, minor);
-		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[1]), data->today, minor);
-		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[2]), data->future, minor);
+		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[0]), data->bank, GLOBALS->minor);
+		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[1]), data->today, GLOBALS->minor);
+		hb_label_set_colvalue(GTK_LABEL(data->TX_balance[2]), data->future, GLOBALS->minor);
 	}
 
 	/* update statusbar */
@@ -1569,9 +1361,9 @@ gboolean minor;
 
 		DB( printf(" %f - %f = %f\n", opeinc, opeexp, opeinc + opeexp) );
 		
-		mystrfmon(buf1, 64-1, opeinc, minor);
-		mystrfmon(buf2, 64-1, -opeexp, minor);
-		mystrfmon(buf3, 64-1, opeinc + opeexp, minor);
+		mystrfmon(buf1, 64-1, opeinc, GLOBALS->minor);
+		mystrfmon(buf2, 64-1, -opeexp, GLOBALS->minor);
+		mystrfmon(buf3, 64-1, opeinc + opeexp, GLOBALS->minor);
 	
 	}
 
@@ -1735,7 +1527,7 @@ gchar *tagstr, *txt;
 						}
 						break;
 					case LST_DSPOPE_PAYEE:
-						ope->payee = ui_pay_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(widget1));
+						ope->payee = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX_ENTRY(widget1));
 						DB( g_print(" -> payee: '%d'\n", ope->payee) );
 						break;
 					case LST_DSPOPE_WORDING:
@@ -1754,7 +1546,7 @@ gchar *tagstr, *txt;
 						if(ope->amount > 0) ope->flags |= OF_INCOME;
 						break;
 					case LST_DSPOPE_CATEGORY:
-						ope->category = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(widget1));
+						ope->category = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX_ENTRY(widget1));
 						//bad .... ope->category = gtk_combo_box_get_active(GTK_COMBO_BOX(widget1));
 						
 						DB( g_print(" -> category: '%d'\n", ope->category) );
@@ -1911,12 +1703,12 @@ Operation *item;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_year), year);
 	g_signal_handler_unblock(data->NB_year, data->handler_id[HID_YEAR]);
 
-	DB( g_printf(" mindate=%d, maxdate=%d %x\n", data->filter->mindate,data->filter->maxdate) );
+	DB( g_print(" mindate=%d, maxdate=%d %x\n", data->filter->mindate,data->filter->maxdate) );
 
-	DB( g_printf(" -> call update visual\n") );
+	DB( g_print(" -> call update visual\n") );
 	account_update(widget, GINT_TO_POINTER(UF_VISUAL));
 
-	DB( g_printf(" -> set range or populate+update sensitive+balance\n") );
+	DB( g_print(" -> set range or populate+update sensitive+balance\n") );
 	if( PREFS->filter_range != 0 )
 		gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_range), PREFS->filter_range);
 	else
@@ -2161,6 +1953,9 @@ GError *error = NULL;
     gtk_box_pack_start (GTK_BOX (hbox), data->NB_year, FALSE, FALSE, 0);
 
 	// info + total
+	hbox = gtk_hbox_new (FALSE, HB_BOX_SPACING);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+
 	label = gtk_label_new(NULL);
 	data->TX_info = label;
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
