@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -33,11 +33,14 @@
 #include "def_budget.h"
 #include "def_pref.h"
 #include "def_operation.h"
+#include "hb_transaction.h"
+
 
 #include "list_account.h"
 #include "list_upcoming.h"
 
 #include "rep_stats.h"
+#include "rep_time.h"
 #include "rep_budget.h"
 #include "rep_over.h"
 #include "rep_car.h"
@@ -100,6 +103,7 @@ static void wallet_action_addoperations(void);
 static void wallet_action_checkautomated(void);
 
 static void wallet_action_statistic(void);
+static void wallet_action_trendtime(void);
 static void wallet_action_budget(void);
 static void wallet_action_overdrawn(void);
 static void wallet_action_carcost(void);
@@ -191,9 +195,10 @@ static GtkActionEntry entries[] = {
   { "Automated"  , NULL             , N_("Check automated..."), NULL,    N_("Insert pending automated transactions"),    G_CALLBACK (wallet_action_checkautomated) },
 
   /* ReportMenu */
-  { "Statistics" , HB_STOCK_REP_STATS , N_("_Statistics..."), NULL,    N_("Open the Statistics report"),    G_CALLBACK (wallet_action_statistic) },
-  { "BudgetR"    , HB_STOCK_REP_BUDGET, N_("B_udget...")    , NULL,    N_("Open the Budget report"),    G_CALLBACK (wallet_action_budget) },
-  { "Overdrawn"  , HB_STOCK_REP_OVER  , N_("Ove_rdrawn...") , NULL,    N_("Open the Overdrawn report"),    G_CALLBACK (wallet_action_overdrawn) },
+  { "Statistics" , HB_STOCK_REP_STATS , N_("_Statistics...") , NULL,    N_("Open the Statistics report"),    G_CALLBACK (wallet_action_statistic) },
+  { "TrendTime"   , HB_STOCK_REP_TIME , N_("_Trend Time...") , NULL,    N_("Open the Trend Time report"),    G_CALLBACK (wallet_action_trendtime) },
+  { "BudgetR"    , HB_STOCK_REP_BUDGET, N_("B_udget...")     , NULL,    N_("Open the Budget report"),    G_CALLBACK (wallet_action_budget) },
+  { "Overdrawn"  , HB_STOCK_REP_OVER  , N_("Ove_rdrawn...")  , NULL,    N_("Open the Overdrawn report"),    G_CALLBACK (wallet_action_overdrawn) },
   { "Carcost"    , HB_STOCK_REP_CAR   , N_("_Car cost...")   , NULL,    N_("Open the Car cost report"),    G_CALLBACK (wallet_action_carcost) },
 
   /* ToolsMenu */
@@ -283,6 +288,7 @@ static const gchar *ui_info =
 
 "    <menu action='ReportMenu'>"
 "      <menuitem action='Statistics'/>"
+"      <menuitem action='TrendTime'/>"
 "      <menuitem action='Overdrawn'/>"
 "      <menuitem action='BudgetR'/>"
 "      <menuitem action='Carcost'/>"
@@ -325,6 +331,7 @@ static const gchar *ui_info =
 "      <separator/>"
 
 "    <toolitem action='Statistics'/>"
+"    <toolitem action='TrendTime'/>"
 "    <toolitem action='Overdrawn'/>"
 "    <toolitem action='BudgetR'/>"
 "    <toolitem action='Carcost'/>"
@@ -552,6 +559,11 @@ static void wallet_action_statistic(void)
 	create_statistic_window();
 }
 
+static void wallet_action_trendtime(void)
+{
+	create_trendtime_window();
+}
+
 static void wallet_action_budget(void)
 {
 	repbudget_window_new();
@@ -679,7 +691,7 @@ GdkPixbuf *pixbuf;
 		  "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, "
 		  "MA 02110-1301, USA.";
 		  
-	static const gchar *copyright = "Copyright \xc2\xa9 1995-2009 - Maxime DOYEN";
+	static const gchar *copyright = "Copyright \xc2\xa9 1995-2010 - Maxime DOYEN";
 
 
 	gtk_about_dialog_set_url_hook (activate_url, NULL, NULL);
@@ -2388,7 +2400,7 @@ GtkAction *action;
 
 		sw = gtk_scrolled_window_new (NULL, NULL);
 		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
-		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 		gtk_container_add (GTK_CONTAINER (align), sw);
 		//gtk_container_set_border_width (GTK_CONTAINER(sw), 5);
 
@@ -2414,7 +2426,7 @@ GtkAction *action;
 
 		sw = gtk_scrolled_window_new (NULL, NULL);
 		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
-		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 		gtk_container_add (GTK_CONTAINER (align), sw);
 
 		treeview = (GtkWidget *)create_list_upcoming();
