@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -45,7 +45,8 @@ struct Preferences *PREFS;
 
 
 /* installation paths */
-static gchar *images_dir  = NULL;
+static gchar *config_dir   = NULL;
+static gchar *images_dir   = NULL;
 static gchar *pixmaps_dir  = NULL;
 static gchar *locale_dir   = NULL;
 static gchar *help_dir     = NULL;
@@ -751,8 +752,8 @@ gchar *group, *filename;
 	keyfile = g_key_file_new();
 	if(keyfile)
 	{
-		filename = g_build_filename(g_get_home_dir (), HB_DATA_PATH, "lastopenedfiles", NULL );
-		//filename = g_strdup_printf("%s/.homebank/lastopenedfiles", g_get_home_dir ());
+
+		filename = g_build_filename(homebank_app_get_config_dir(), "lastopenedfiles", NULL );
 
 		DB( g_print(" -> filename: %s\n", filename) );
 
@@ -808,8 +809,7 @@ guint length;
 
 			//DB( g_print(" keyfile:\n%s\nlen=%d\n", contents, length) );
 
-			//filename = g_strdup_printf("%s/" HB_DATA_PATH "/lastopenedfiles", g_get_home_dir ());
-			filename = g_build_filename(g_get_home_dir (), HB_DATA_PATH, "lastopenedfiles", NULL );
+			filename = g_build_filename(homebank_app_get_config_dir(), "lastopenedfiles", NULL );
 			g_file_set_contents(filename, contents, length, NULL);
 			g_free(filename);
 
@@ -930,7 +930,8 @@ homebank_register_stock_icons()
 		"prf-columns",
 		"prf-display",
 		"prf-euro",
-		"prf-report"
+		"prf-report",
+		"prf-import"
 	};
 
 	factory = gtk_icon_factory_new ();
@@ -969,6 +970,12 @@ gchar *pathfilename;
 }
 */
 
+const gchar *
+homebank_app_get_config_dir (void)
+{
+	return config_dir;
+}
+
 const gchar *
 homebank_app_get_images_dir (void)
 {
@@ -1013,6 +1020,9 @@ build_package_paths (void)
 	help_dir     = g_strdup (HOMEBANK_HELPDIR);
 #endif
 
+	config_dir   = g_build_filename(g_get_user_config_dir(), HB_DATA_PATH, NULL);
+	
+	DB( g_print("config_dir : %s\n", config_dir) );
 	DB( g_print("images_dir : %s\n", images_dir) );
 	DB( g_print("pixmaps_dir: %s\n", pixmaps_dir) );
 	DB( g_print("locale_dir : %s\n", locale_dir) );
@@ -1024,13 +1034,33 @@ build_package_paths (void)
 
 
 
+static gboolean homebank_check_app_dir_migrate_file(gchar *srcdir, gchar *dstdir, gchar *filename)
+{
+gchar *srcpath;
+gchar *dstpath;
+gchar *buffer;
+gsize length;
+GError *error = NULL;
+gboolean retval = FALSE;
 
+	srcpath = g_build_filename(srcdir, filename, NULL );
+	dstpath = g_build_filename(dstdir, filename, NULL );
+	
+	if (g_file_get_contents (srcpath, &buffer, &length, &error))
+	{
+		if(g_file_set_contents(dstpath, buffer, length, NULL))
+		{
+			//g_print("sould remove %s\n", srcpath);
+			g_remove(srcpath);
+			retval = TRUE;
+		}
+	}
 
+	g_free(dstpath);
+	g_free(srcpath);
 
-
-
-
-
+	return retval;
+}
 
 /*
  * check/create user home directory for .homebank (HB_DATA_PATH) directory
@@ -1038,19 +1068,43 @@ build_package_paths (void)
 static void homebank_check_app_dir()
 {
 gchar *homedir;
+const gchar *configdir;
 gboolean exists;
 
 	DB( g_print("homebank_check_app_dir()\n") );
 
-	//homedir = g_strdup_printf("%s/" HB_DATA_PATH, g_get_home_dir ());
-	homedir = g_build_filename(g_get_home_dir (), HB_DATA_PATH, NULL );
-	exists = g_file_test(homedir, G_FILE_TEST_IS_DIR);
-	if(!exists)
-		g_mkdir(homedir, 0755);
+	/* check for XDG .config/homebank */
+	configdir = homebank_app_get_config_dir();
+	exists = g_file_test(configdir, G_FILE_TEST_IS_DIR);
+	if(exists)
+	{
+		/* just update folder security */
+		g_chmod(configdir, 0700);
+	}
+	else
+	{
+		/* create the config dir */
+		g_mkdir(configdir, 0755);
+		g_chmod(configdir, 0700);
 
-	/* security */
-	g_chmod(homedir, 0700);
-	g_free(homedir);
+		/* any old homedir configuration out there ? */
+		homedir = g_build_filename(g_get_home_dir (), ".homebank", NULL );
+		exists = g_file_test(homedir, G_FILE_TEST_IS_DIR);
+		if(exists)
+		{
+		gboolean f1, f2;
+			/* we must do the migration properly */
+			f1 = homebank_check_app_dir_migrate_file(homedir, config_dir, "preferences");
+			f2 = homebank_check_app_dir_migrate_file(homedir, config_dir, "lastopenedfiles");
+			if(f1 && f2)
+			{
+				//g_print("sould remove %s\n", homedir);
+				g_rmdir(homedir);
+			}
+		}
+		g_free(homedir);
+	}
+	
 }
 
 
@@ -1097,6 +1151,8 @@ static void homebank_cleanup()
 		g_free(GLOBALS);
 	}
 
+	g_free (config_dir);
+	g_free (images_dir);
 	g_free (pixmaps_dir);	
 	g_free (locale_dir);
 	g_free (help_dir);
@@ -1162,19 +1218,18 @@ GDate *date;
 
 	//debug
 	#if MYDEBUG == 1
-	/*
+
 	g_print("user_name: %s\n", g_get_user_name ());
 	g_print("real_name: %s\n", g_get_real_name ());
 	g_print("user_cache_dir: %s\n", g_get_user_cache_dir());
 	g_print("user_data_dir: %s\n", g_get_user_data_dir ());
 	g_print("user_config_dir: %s\n", g_get_user_config_dir ());
-	//g_print("system_data_dirs: %s\n", g_get_system_data_dirs ());
-	//g_print("system_config_dirs: %s\n", g_get_system_config_dirs ());
+	g_print("system_data_dirs: %s\n", g_get_system_data_dirs ());
+	g_print("system_config_dirs: %s\n", g_get_system_config_dirs ());
 
 	g_print("home_dir: %s\n", g_get_home_dir ());
 	g_print("tmp_dir: %s\n", g_get_tmp_dir ());
 	g_print("current_dir: %s\n", g_get_current_dir ());
-	*/
 
 	#endif
 
