@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -59,15 +59,16 @@
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 #define HB_UNSTABLE			0
+#define HB_VERSION			"4.2.1"
 
 #define FILE_VERSION		0.4
 
 #if HB_UNSTABLE != 1
 	#define	PROGNAME		"HomeBank"
-	#define HB_DATA_PATH	".homebank"
+	#define HB_DATA_PATH	"homebank"
 #else
-	#define	PROGNAME		"HomeBank (unstable)"
-	#define HB_DATA_PATH	".homebank_unstable"
+	#define	PROGNAME		"HomeBank " HB_VERSION " (unstable)"
+	#define HB_DATA_PATH	"homebank_unstable"
 #endif
 
 #ifdef G_OS_WIN32
@@ -75,18 +76,14 @@
 #define LOCALE_DIR      "locale"
 #define PIXMAPS_DIR     "images"
 #define HELP_DIR        "help"
-#define PACKAGE_VERSION "4.1"
+#define PACKAGE_VERSION HB_VERSION
 #define PACKAGE         "homebank"
-#define VERSION         "4.1"
+#define VERSION         HB_VERSION
 //#define NOOFX
 
 #define ENABLE_NLS 1
 #endif
 
-
-/* for operation dialog */
-#define GTK_RESPONSE_ADD	 1
-
 /* container spacing */
 #define HB_MAINBOX_SPACING	12
 #define HB_BOX_SPACING		6
@@ -94,6 +91,14 @@
 #define HB_TABROW_SPACING	6
 #define HB_TABCOL_SPACING	6
 
+/* for operation dialog */
+#define GTK_RESPONSE_ADD	 1
+
+/* default zoomx for charts */
+#define GTK_CHART_MINBARW 	8
+#define GTK_CHART_BARW 		24
+#define GTK_CHART_MAXBARW 	64
+
 enum
 {
 	FILETYPE_UNKNOW,
@@ -126,6 +131,7 @@ enum
 #define HB_STOCK_OPE_REMIND      "hb-ope-remind"
 #define HB_STOCK_OPE_AUTO        "hb-ope-auto"
 #define HB_STOCK_REP_STATS       "hb-rep-stats"
+#define HB_STOCK_REP_TIME        "hb-rep-time"
 #define HB_STOCK_REP_OVER        "hb-rep-over"
 #define HB_STOCK_REP_BUDGET      "hb-rep-budget"
 #define HB_STOCK_REP_CAR         "hb-rep-car"
@@ -189,6 +195,7 @@ gboolean homebank_lastopenedfiles_save(void);
 
 void homebank_window_set_icon_from_file(GtkWindow *window, gchar *filename);
 
+const gchar *homebank_app_get_config_dir (void);
 const gchar *homebank_app_get_images_dir (void);
 const gchar *homebank_app_get_pixmaps_dir (void);
 const gchar *homebank_app_get_locale_dir (void);
