@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2009 Maxime DOYEN
+ *	Copyright (C) 1995-2010 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -119,28 +119,37 @@ hb_qif_parser_get_amount(gchar *string)
 {
 gdouble amount;
 gint l, i;
-char *new_str, *p, sep;
-gint cc = 0;
-gint pc = 0;
+char *new_str, *p;
+gint  ndcount = 0;
+char gc, dc;
 
 	amount = 0.0;
+	gc = dc = '?';
 
 	l = strlen(string);
 
-	/* count comma and point digits */
-	for(i=0;i<l;i++)
-	{
-		if( string[i] == ',') cc++;
-		else
-			if( string[i] == '.') pc++;
-	}		
-
-	/* determine decimal separator */
-	sep = '.';
-	if(cc == 1)
-		sep = ',';
+	// the first non-digit is a grouping, or a decimal separator
+	// if the non-digit is after a 3 digit serie, it might be a grouping
 	
-	 DB( g_print(" %s comma: %d, point: %d, sep:%c\n", string, cc, pc, sep) );
+	for(i=l;i>=0;i--)
+	{
+		if( string[i] == '-') continue;
+
+		if( g_ascii_isdigit( string[i] ))
+		{
+			ndcount++;
+		}
+		else
+		{
+			if(ndcount == 3)
+				gc = string[i];
+			else
+				dc = string[i];
+			ndcount = 0;
+		}
+	}
+
+	 DB( g_print(" %s :: gc='%c', ds='%c'\n", string, gc, dc) );
 
 
 	new_str = g_malloc (l+1);
@@ -152,7 +161,7 @@ gint pc = 0;
 			*p++ = string[i];
 		}
 		else
-			if( string[i] == sep )
+			if( string[i] == dc )
 				*p++ = '.';
 	}
 	*p++ = '\0';
