@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2009 Maxime DOYEN
+ *	Copyright (C) 1995-2010 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -553,8 +553,27 @@ Operation *newope;
 		newope->wording = g_strdup(data.name);
 	}
 
-	//todo: memo ?
+//memo ( new for v4.2)
+	if(data.memo_valid==true)
+	{
+		gchar *old = NULL;
 
+		switch(PREFS->dtex_ofxmemo)
+		{
+			case 1:	//add to info
+				old = newope->info;
+				newope->info = g_strjoin(" ", old, data.memo, NULL);
+				if(old) g_free(old);
+				break;
+				
+			case 2: //add to description
+				old = newope->wording;
+				newope->wording = g_strjoin(" ", old, data.memo, NULL);
+				if(old) g_free(old);
+				break;
+		}
+	}
+	
 // payment
 	if(data.transactiontype_valid==true)
 	{
