@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -62,6 +62,7 @@ struct repbudget_data
 	GtkWidget	*CY_for;
 	GtkWidget	*CY_kind;
 	GtkWidget	*CY_view;
+	GtkWidget	*RG_zoomx;
 	GtkWidget	*LV_report;
 
 	GtkWidget	*PO_mindate, *PO_maxdate;
@@ -833,17 +834,16 @@ next1:
 static void repbudget_update_total(GtkWidget *widget, gpointer user_data)
 {
 struct repbudget_data *data;
-gboolean minor;
 
 	DB( g_print("(repbudget) update total\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
+	GLOBALS->minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
 
-	hb_label_set_colvalue(GTK_LABEL(data->TX_total[0]), data->total_spent, minor);
-	hb_label_set_colvalue(GTK_LABEL(data->TX_total[1]), data->total_budget, minor);
-	hb_label_set_colvalue(GTK_LABEL(data->TX_total[2]), budget_compute_decay(data->total_budget, data->total_spent), minor);
+	hb_label_set_colvalue(GTK_LABEL(data->TX_total[0]), data->total_spent, GLOBALS->minor);
+	hb_label_set_colvalue(GTK_LABEL(data->TX_total[1]), data->total_budget, GLOBALS->minor);
+	hb_label_set_colvalue(GTK_LABEL(data->TX_total[2]), budget_compute_decay(data->total_budget, data->total_spent), GLOBALS->minor);
 
 }
 
@@ -897,6 +897,23 @@ struct repbudget_data *data;
 
 }
 
+static void repbudget_zoomx_callback(GtkWidget *widget, gpointer user_data)
+{
+struct repbudget_data *data;
+gdouble value;
+
+	DB( g_print("(repbudget) zoomx\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	value = gtk_range_get_value(GTK_RANGE(data->RG_zoomx));
+
+	DB( g_print(" + scale is %d\n", value) );
+
+	gtk_chart_set_barw(GTK_CHART(data->RE_bar), value);
+
+}
+
 static void repbudget_toggle(GtkWidget *widget, gpointer user_data)
 {
 struct repbudget_data *data;
@@ -1047,6 +1064,13 @@ GError *error = NULL;
 	data->CY_view = widget;
 	gtk_table_attach_defaults (GTK_TABLE (table), data->CY_view, 1, 2, row, row+1);
 
+	row++;
+	label = make_label(_("_Zoom X:"), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = make_scale(label);
+	data->RG_zoomx = widget;
+	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 2, row, row+1);
+	
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("_Minor currency"));
 	data->CM_minor = widget;
@@ -1191,7 +1215,7 @@ GError *error = NULL;
 
 	widget = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	treeview = create_list_budget();
 	data->LV_report = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
@@ -1201,7 +1225,7 @@ GError *error = NULL;
 	widget = gtk_scrolled_window_new (NULL, NULL);
 	data->GR_detail = widget;
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	treeview = create_list_operation(PREFS->lst_ope_columns);
 	data->LV_detail = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
@@ -1235,6 +1259,8 @@ GError *error = NULL;
     g_signal_connect (data->CY_kind, "changed", G_CALLBACK (repbudget_compute), (gpointer)data);
     g_signal_connect (data->CY_view, "changed", G_CALLBACK (repbudget_compute), (gpointer)data);
 
+	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (repbudget_zoomx_callback), NULL);
+
     data->handler_id[HID_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repbudget_date_change), (gpointer)data);
     data->handler_id[HID_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repbudget_date_change), (gpointer)data);
 
@@ -1268,7 +1294,7 @@ GError *error = NULL;
 	GDate *date;
 	guint year;
 
-		da_operation_sort(GLOBALS->ope_list);
+		GLOBALS->ope_list = da_operation_sort(GLOBALS->ope_list);
 		list = g_list_first(GLOBALS->ope_list);
 		data->mindate = ((Operation *)list->data)->date;
 		list = g_list_last(GLOBALS->ope_list);
