@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -234,8 +234,8 @@ static gint repcar_transaction_compare_func(CarCost *a, CarCost *b)
 {
 gint retval;
 
-	retval = (gint)(a->ope->date - b->ope->date);
-	if( retval == 0 )
+	//retval = (gint)(a->ope->date - b->ope->date);
+	//if( retval == 0 )
 		retval = a->meter - b->meter;
 
 	return retval;
@@ -259,6 +259,8 @@ guint32 catkey;
 
 	DB( g_print(" -> active cat is %d\n", catkey) );
 
+	if(catkey == -1) return;
+	
 	// clear the glist
 	da_carcost_destroy(data->car_list);
 	data->car_list = NULL;
@@ -301,7 +303,7 @@ guint32 catkey;
 		list = g_list_next(list);
 	}
 
-	// sort by date and then meter #399170
+	// sort by meter #399170
 	data->car_list = g_list_sort(data->car_list, (GCompareFunc)repcar_transaction_compare_func);
 
 	repcar_update(widget, NULL);
@@ -400,7 +402,8 @@ guint lastmeter = 0;
 
 
 	gdouble coef = data->total_dist ? 100 / (gdouble)data->total_dist : 0;
-	gboolean minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
+
+	GLOBALS->minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
 
 
 		DB( g_print(" coef = 100 / %.2f = %.2f\n", (gdouble)data->total_dist, coef) );
@@ -419,13 +422,13 @@ guint lastmeter = 0;
 		g_free(buf);
 
 		// 100km fuelcost
-		hb_label_set_colvalue(GTK_LABEL(data->LA_avera[CAR_RES_FUELCOST]), data->total_fuelcost * coef, minor);
+		hb_label_set_colvalue(GTK_LABEL(data->LA_avera[CAR_RES_FUELCOST]), data->total_fuelcost * coef, GLOBALS->minor);
 
 		// 100km other cost
-		hb_label_set_colvalue(GTK_LABEL(data->LA_avera[CAR_RES_OTHERCOST]), data->total_misccost * coef, minor);
+		hb_label_set_colvalue(GTK_LABEL(data->LA_avera[CAR_RES_OTHERCOST]), data->total_misccost * coef, GLOBALS->minor);
 
 		// 100km cost
-		hb_label_set_colvalue(GTK_LABEL(data->LA_avera[CAR_RES_TOTALCOST]), (data->total_fuelcost + data->total_misccost) * coef, minor);
+		hb_label_set_colvalue(GTK_LABEL(data->LA_avera[CAR_RES_TOTALCOST]), (data->total_fuelcost + data->total_misccost) * coef, GLOBALS->minor);
 
 
 		// row 2 is for total
@@ -447,13 +450,13 @@ guint lastmeter = 0;
 		g_free(buf);
 
 		// total fuelcost
-		hb_label_set_colvalue(GTK_LABEL(data->LA_total[CAR_RES_FUELCOST]), data->total_fuelcost, minor);
+		hb_label_set_colvalue(GTK_LABEL(data->LA_total[CAR_RES_FUELCOST]), data->total_fuelcost, GLOBALS->minor);
 
 		// total other cost
-		hb_label_set_colvalue(GTK_LABEL(data->LA_total[CAR_RES_OTHERCOST]), data->total_misccost, minor);
+		hb_label_set_colvalue(GTK_LABEL(data->LA_total[CAR_RES_OTHERCOST]), data->total_misccost, GLOBALS->minor);
 
 		// total cost
-		hb_label_set_colvalue(GTK_LABEL(data->LA_total[CAR_RES_TOTALCOST]), data->total_fuelcost + data->total_misccost, minor);
+		hb_label_set_colvalue(GTK_LABEL(data->LA_total[CAR_RES_TOTALCOST]), data->total_fuelcost + data->total_misccost, GLOBALS->minor);
 
 
 }
@@ -498,7 +501,7 @@ static void repcar_setup(struct repcar_data *data)
 	GList *list;
 
 		//get our min max date
-		da_operation_sort(GLOBALS->ope_list);
+		GLOBALS->ope_list = da_operation_sort(GLOBALS->ope_list);
 		list = g_list_first(GLOBALS->ope_list);
 		data->mindate = ((Operation *)list->data)->date;
 		list = g_list_last(GLOBALS->ope_list);
@@ -756,7 +759,7 @@ gint row, col;
 	//detail
 	widget = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
 	treeview = create_list_repcar();
 	data->LV_report = treeview;
