@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -65,6 +65,7 @@ struct statistic_data
 	GtkWidget	*CM_minor;
 	GtkWidget	*CY_for;
 	GtkWidget	*CY_view;
+	GtkWidget	*RG_zoomx;
 	GtkWidget	*LV_report;
 	GtkWidget	*CM_byamount;
 
@@ -1249,6 +1250,24 @@ struct statistic_data *data;
 
 }
 
+static void statistic_zoomx_callback(GtkWidget *widget, gpointer user_data)
+{
+struct statistic_data *data;
+gdouble value;
+
+	DB( g_print("(statistic) zoomx\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	value = gtk_range_get_value(GTK_RANGE(data->RG_zoomx));
+
+	DB( g_print(" + scale is %d\n", value) );
+
+	gtk_chart_set_barw(GTK_CHART(data->RE_bar), value);
+
+}
+
+
 /*
 ** change the chart rate columns visibility
 */
@@ -1278,21 +1297,19 @@ GtkTreeViewColumn *column;
 static void statistic_toggle_minor(GtkWidget *widget, gpointer user_data)
 {
 struct statistic_data *data;
-gboolean minor;
 
 	DB( g_print("(statistic) toggle\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
+	GLOBALS->minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
+	
 	statistic_update_total(widget,NULL);
 
 	//wallet_update(data->LV_acc, (gpointer)4);
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_report));
-
-	minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
-	gtk_chart_show_minor(GTK_CHART(data->RE_bar), minor);
-	gtk_chart_show_minor(GTK_CHART(data->RE_pie), minor);
-
+	gtk_chart_show_minor(GTK_CHART(data->RE_bar), GLOBALS->minor);
+	gtk_chart_show_minor(GTK_CHART(data->RE_pie), GLOBALS->minor);
 }
 
 
@@ -1363,7 +1380,7 @@ static void statistic_setup(struct statistic_data *data)
 	GList *list;
 
 		//get our min max date
-		da_operation_sort(GLOBALS->ope_list);
+		GLOBALS->ope_list = da_operation_sort(GLOBALS->ope_list);
 		list = g_list_first(GLOBALS->ope_list);
 		data->filter->mindate = ((Operation *)list->data)->date;
 		list = g_list_last(GLOBALS->ope_list);
@@ -1525,6 +1542,13 @@ GError *error = NULL;
 	data->CY_view = widget;
 	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 2, row, row+1);
 
+	row++;
+	label = make_label(_("_Zoom X:"), 0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	widget = make_scale(label);
+	data->RG_zoomx = widget;
+	gtk_table_attach_defaults (GTK_TABLE (table), widget, 1, 2, row, row+1);
+	
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("By _amount"));
 	data->CM_byamount = widget;
@@ -1683,7 +1707,7 @@ GError *error = NULL;
 	widget = gtk_scrolled_window_new (NULL, NULL);
 	//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (widget), GTK_CORNER_TOP_RIGHT);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	treeview = create_list_statistic();
 	data->LV_report = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
@@ -1694,7 +1718,7 @@ GError *error = NULL;
 	data->GR_detail = widget;
 	//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (widget), GTK_CORNER_TOP_RIGHT);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	treeview = create_list_operation(PREFS->lst_ope_columns);
 	data->LV_detail = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
@@ -1741,6 +1765,9 @@ GError *error = NULL;
     g_signal_connect (data->CY_for, "changed", G_CALLBACK (statistic_compute), (gpointer)data);
     data->handler_id[HID_VIEW] = g_signal_connect (data->CY_view, "changed", G_CALLBACK (statistic_compute), (gpointer)data);
 
+	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (statistic_zoomx_callback), NULL);
+
+	
 	g_signal_connect (data->CM_byamount, "toggled", G_CALLBACK (statistic_update), NULL);
 
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), "changed", G_CALLBACK (statistic_selection), NULL);
