@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -71,7 +71,7 @@ gchar *name = NULL;
  *
  */
 guint32
-ui_cat_comboboxentry_get_key(GtkComboBoxEntry *entry_box)
+ui_cat_comboboxentry_get_key_add_new(GtkComboBoxEntry *entry_box)
 {
 Category *item;
 gchar *name;
@@ -97,6 +97,33 @@ gchar *name;
 }
 
 
+/**
+ * ui_cat_comboboxentry_get_key:
+ * 
+ * get the key of the active category or -1
+ * 
+ * Return value: the key or -1
+ *
+ */
+guint32
+ui_cat_comboboxentry_get_key(GtkComboBoxEntry *entry_box)
+{
+Category *item;
+gchar *name;
+
+	DB( g_print ("ui_cat_comboboxentry_get_key()\n") );
+
+	name = (gchar *)gtk_entry_get_text(GTK_ENTRY (GTK_BIN (entry_box)->child));
+	if( name == NULL)
+		return -1;
+
+	item = da_cat_get_by_fullname(name);
+	if(item != NULL)
+		return item->key;
+
+	return -1;
+}
+
 gboolean
 ui_cat_comboboxentry_set_active(GtkComboBoxEntry *entry_box, guint32 key)
 {
@@ -1212,7 +1239,7 @@ GtkTreeIter			 iter;
 			{
 			guint dstkey;
 
-				dstkey = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(getwidget));
+				dstkey = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX_ENTRY(getwidget));
 
 				DB( g_print(" moving to %d\n", dstkey) );
 
