@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2009 Maxime DOYEN
+ *  Copyright (C) 1995-2010 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -63,7 +63,7 @@ gchar *name = NULL;
 
 
 /**
- * ui_pay_comboboxentry_get_key:
+ * ui_pay_comboboxentry_get_key_add_new:
  * 
  * get the key of the active payee
  * and create the payee if it do not exists
@@ -72,7 +72,7 @@ gchar *name = NULL;
  *
  */
 guint32
-ui_pay_comboboxentry_get_key(GtkComboBoxEntry *entry_box)
+ui_pay_comboboxentry_get_key_add_new(GtkComboBoxEntry *entry_box)
 {
 gchar *name;
 Payee *item;
@@ -95,6 +95,30 @@ Payee *item;
 	return item->key;
 }
 
+/**
+ * ui_pay_comboboxentry_get_key:
+ * 
+ * get the key of the active payee
+ * 
+ * Return value: the key or 0
+ *
+ */
+guint32
+ui_pay_comboboxentry_get_key(GtkComboBoxEntry *entry_box)
+{
+gchar *name;
+Payee *item;
+
+	name = ui_pay_comboboxentry_get_name(entry_box);
+	item = da_pay_get_by_name(name);
+	g_free(name);
+
+	if( item != NULL )
+		return item->key;
+
+	return -1;
+}
+
 gboolean
 ui_pay_comboboxentry_set_active(GtkComboBoxEntry *entry_box, guint32 key)
 {
@@ -773,7 +797,7 @@ GtkTreeIter			 iter;
 			{
 			guint newpayee;
 
-				newpayee = ui_pay_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(getwidget));
+				newpayee = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX_ENTRY(getwidget));
 			
 				gtk_combo_box_get_active(GTK_COMBO_BOX(getwidget));
 
